@@ -25,8 +25,12 @@
  *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR  *
  *   OTHER DEALINGS IN THE SOFTWARE.                                        *
  *                                                                          *
- *   See the GNU Lesser General Public License (LICENSE.LGPL) and the MIT   *
- *   licence (LICENSE.MIT) for more details.                                *
+ *   See LICENCES for more details.                                         *
+ *                                                                          *
+ *   SPDX-FileCopyrightText: Copyright 2005-2025                            *
+ *       - Pierre-Henri WUILLEMIN(_at_LIP6)                                 *
+ *       - Christophe GONZALES(_at_AMU)                                     *
+ *   SPDX-License-Identifier: LGPL-3.0-or-later OR MIT                      *
  *                                                                          *
  *   Contact  : info_at_agrum_dot_org                                       *
  *   homepage : http://agrum.gitlab.io                                      *
@@ -584,6 +588,15 @@ namespace gum {
     // Hence, for speedup, we do not update the end iterator
   }
 
+  template < typename Key >
+  Key Set< Key >::popFirst() {
+    if (this->empty()) { GUM_ERROR(NotFound, "Cannot popFirst from an empty set"); }
+
+    auto key = *this->begin();
+    this->erase(key);
+    return key;
+  }
+
   // erases an element from the set
   template < typename Key >
   INLINE void Set< Key >::erase(const SetIteratorSafe< Key >& iter) {
